using UnityEngine;
using System.Collections.Generic;

public class TerrainShapeApplier : MonoBehaviour
{
    private struct TerrainInformation
    {
        public Transform parent;
        public TerrainData data;
        public Terrain terrain;
        public float[,] heights;
        public Vector3 worldPosition;
        public float subdivisionOffsetX, subdivisionOffsetY;
    }

    private Queue<TerrainInformation> heights = new();

    public bool QueueEmpty => heights.Count == 0;

    public TerrainMaster master;

    public void ApplyHeights(Transform parent, Terrain terrain, TerrainData data,
        Vector3 worldPosition, float[,] heights)
    {
        TerrainInformation height = new()
        {
            parent = parent,
            data = data,
            terrain = terrain,
            heights = heights,
            worldPosition = worldPosition
        };

        this.heights.Enqueue(height);
    }

    private void Update()
    {
        if (heights.TryDequeue(out TerrainInformation height))
        {
            if (!height.terrain)
            {
                // First time set up
                var terrainGO = Terrain.CreateTerrainGameObject(height.data);
                terrainGO.transform.SetParent(height.parent, false);
                height.terrain = terrainGO.GetComponent<Terrain>();

                master.ChunkInitApply();
            }
            
            height.data.SetHeights(0, 0, height.heights);
            height.parent.position = height.worldPosition;
        }
    }
}